@@ -1,8 +1,9 @@
 package Mojo::Pua;
 use Evo 'Evo::Export *; Evo::Promise *; ::Class';
 
-our $VERSION = '0.002';    # VERSION
-use constant SINGLE => our $SINGLE = Mojo::Pua::Class->new;
+our $VERSION = '0.003';    # VERSION
+use constant SINGLE => our $SINGLE
+  = Mojo::Pua::Class->new(max_connections => 100);
 
 sub pua_delete(@opts) : Export  { SINGLE()->delete(@_) }
 sub pua_get(@opts) : Export     { SINGLE()->get(@_) }
@@ -29,17 +30,17 @@ Mojo::Pua - HTTP Client + Evo::Promises
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
   use Evo 'Mojo::Pua *; Mojo::IOLoop';
 
-  pua_get('http://alexbyk.com')
+  pua_get('http://alexbyk.com/')
 
     ->then(sub($res) { say $res->dom->at('title') })
 
-    ->catch(sub($err) { say "$err", $err->res->dom->at('title') })
+    ->catch(sub($err) { say "$err"; $err->res and say $err->res->body })
 
     ->finally(sub { Mojo::IOLoop->stop });
 
